# LGPy
LGPy is a linear genetic programming library implemented in Python to evolve problems. In linear programming, a sequence of assembly-like instructions dictates the flow of a program. Each hardware in LGPy contains a set of instructions and a memory buffer that acts as its program.

## Installing
```pip install LGPy```

## Examples
Located in: ```LGPy/Examples/```

```python3 even_odd.py```


## Authors
* NateRiz

## Acknowledgements
* Inspiration from SignalGP: https://github.com/devosoft/Empirical
